/**
  *  \file client/tiles/ioninfo.cc
  *  \brief Ion Storm Information Tile
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/ioninfo.h"
#include "game/ion.h"
#include "cpluslib/format.h"
#include "gfx/gfxcontext.h"
#include "game/tables.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

/** Constructor.
    \param type Object type to display */
WIonStormInfoTile::WIonStormInfoTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(25, 5), type)
{ }

void
WIonStormInfoTile::drawData(GfxCanvas& can)
{
    // |----9em-----|------16em----------------|
    // Centered at:  1234,2456
    // Radius:       100 ly
    // Movement:     99, warp 10
    // Voltage:      111 MeV
    //               class 3 (strong)
    // PCC 1.x has a line "Id Number: 17: Elisabeth" but we have that in the header

    GfxRect pos  = getInnerSize(0, 0);
    const int dy = font_heights[FONT_NORMAL];
    const int x0 = 0;
    const int x1 = font_ems[FONT_NORMAL]*9;
    const int w  = pos.w - x1;
    int y = 0;

    GIonStorm* ion = dynamic_cast<GIonStorm*>(getObject());
    if (!ion)
        return;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setColor(UIColor::tc_Static);
    ctx.setSolidBackground();

    // Line 1:
    outText (ctx, x0, y, _("Centered at:"));
    outTextF(ctx, x1, y, w, format("%d,%d", ion->getPos().x, ion->getPos().y));
    y += dy;

    // Line 2:
    outText (ctx, x0, y, _("Radius:"));
    outTextF(ctx, x1, y, w, format(_("%d ly"), ion->getRadius()));
    y += dy;

    // Line 3:
    outText (ctx, x0, y, _("Movement:"));
    outTextF(ctx, x1, y, w, format(_("%d\xC2\xB0, warp %d"), ion->getHeading(), ion->getSpeed()));
    y += dy;

    // Line 4+5:
    outText (ctx, x0, y, _("Voltage:"));
    outTextF(ctx, x1, y, w, format(ion->isGrowing() ? _("%d MeV, growing") : _("%d MeV, weakening"), ion->getVoltage()));
    y += dy;

    outTextF(ctx, x1, y, w, format(_("Class %d (%s)"), ion->getClass(), getIonStormClassName(ion->getVoltage())));
    y += dy;
}
