/**
  *  \file client/wedit.h
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WEDIT_H
#define PCC_V2_CLIENT_WEDIT_H

#include <vector>
#include "ui/ui.h"
#include "cpluslib/string.h"

// FIXME: maybe it makes sense to split this into an 'editor' class
// and a widget.
class WEditor : public UIWidget {
 public:
    typedef std::vector<string_t> vec_t;
    typedef vec_t::size_type      line_t;
    typedef string_t::size_type   col_t;

 private:
    vec_t      content;
    col_t      max_line_length; ///< Maximum line length.
    line_t     min_line;        ///< Minimum line accessible to user.
    line_t     max_line;        ///< First line not accessible to user.
    line_t     max_storage;     ///< Maximum number of lines stored.

    col_t      cursor_x;
    line_t     cursor_y;

    void   insertNoRedraw(string_t s);
    void   wrapLineNoRedraw(line_t line, col_t len);
    void   splitLineNoRedraw(line_t line, col_t col);
    void   doDelete(bool forward);

 public:
    WEditor(int id);
    ~WEditor();

    void   setMaxLineLength(col_t len);
    void   setMaxStoredLines(line_t lines);
    void   setUserLineRestrictions(line_t min, line_t max);

    col_t  getMaxLineLength() const { return max_line_length; }
    line_t getUserMinimumLine() const { return min_line; }
    line_t getUserMaximumLine() const { return max_line; }
    line_t getMaxStoredLines() const { return max_storage; }
    line_t getNumStoredLines() const { return content.size(); }

    void   insertLine(line_t line);
    void   deleteLine(line_t line, line_t count = 1);

    string_t getLine(line_t line) const;
    void     setLine(line_t line, string_t text);

    string_t getContentAsString() const;
    string_t getContentAsString(line_t begin, line_t end) const;

    void     drawContent(GfxCanvas& can);
    void     getLayoutInfo(LayoutInfo& li);
    bool     handleEvent(const UIEvent& e, bool second_pass);

    void     insertString(string_t s);

    line_t   getCurrentLine() const { return cursor_y; }
    col_t    getCurrentColumn() const { return cursor_x; }
};

#endif
