/**
  *  \file client/widgets/lrupopup.h
  *  \brief LRU List Popup
  */
#ifndef PCC_V2_CLIENT_WIDGETS_LRUPOPUP_H
#define PCC_V2_CLIENT_WIDGETS_LRUPOPUP_H

#include <vector>
#include "ui/ui.h"
#include "client/lru.h"

/** LRU List Popup. This provides the logic to create a LRU list
    popup. It is (currently) not a widget by itself.

    To use, call withList() once or many times to add items. Then,
    call doPopup() to display the list. It is permitted to change the
    lists between the calls, so it is permitted to keep an instance of
    WLRUPopup around (but it is also sensible and cheap to construct
    it on-the-fly when needed). */
class WLRUPopup {
 public:
    WLRUPopup();
    WLRUPopup& withList(string_t name, LRUList& list);
    const LRUListItem* doPopup(string_t current, UIWidget& anchor);

 private:
    std::vector<string_t> names;
    std::vector<LRUList*> lists;
};

#endif
