/**
  *  \file int/if/baseif.h
  *  \brief Interpreter Game Interface: Starbase Properties
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_BASEIF_H
#define PCC_V2_INT_IF_BASEIF_H

#include "cpluslib/types.h"

class IntValue;
class GObject;
class GPlanet;
class IntExecutionContext;
class IntArgBlock;
struct TBuildOrder;

enum IntBaseProperty {
    ibpBaseDamage,
    ibpBaseDefense,
    ibpBaseDefenseMax,
    ibpBaseFighters,
    ibpBaseFightersMax,
    ibpBeamTech,
    ibpBuildBeam,
    ibpBuildBeamCount,
    ibpBuildEngine,
    ibpBuildFlag,
    ibpBuildHull,
    ibpBuildHullName,
    ibpBuildHullShort,
    ibpBuildQueuePos,
    ibpBuildTorp,
    ibpBuildTorpCount,
    ibpEngineTech,
    ibpHullTech,
    ibpMission,
    ibpMissionName,
    ibpShipyardAction,
    ibpShipyardId,
    ibpShipyardName,
    ibpShipyardStr,
    ibpTorpedoTech,

    ibpEngineStorage,
    ibpHullStorage,
    ibpBeamStorage,
    ibpLauncherStorage,
    ibpAmmoStorage
};

IntValue* getBaseProperty(const GPlanet& pl, IntBaseProperty ibp);
void      setBaseProperty(GPlanet& pl, IntBaseProperty ibp, IntValue* value);
bool      parseBuildShipCommand(IntArgBlock& args, TBuildOrder& o);

void IFBaseBuildFighters(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildEngines(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildHulls(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildLaunchers(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildBeams(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildTorps(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseBuildShip(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseFixShip(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseRecycleShip(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseSetMission(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);
void IFBaseSetTech(GObject& obj, IntExecutionContext& exc, IntArgBlock& args);

#endif
