/**
  *  \file int/vmioinst.cc
  *  \brief Interpreter: Virtual Machine I/O Class Instances
  *
  *  Some IntValue descendants refer to IntVMSaveContext /
  *  IntVMLoadContext (of course, that's what it is for). Since those
  *  in turn refer to IntExecutionContext, IntValue indirectly pulls
  *  in the whole interpreter, even if that isn't actually needed.
  *
  *  To reduce these dependencies, the VM I/O Context instance
  *  pointers have been placed separately. In addition, all methods
  *  called via an instance pointer have been made virtual. Currently,
  *  those are
  *  - IntVMSaveContext::addBCO
  *  - IntVMSaveContext::addArray
  *  - IntVMSaveContext::addHash
  *  This way, such calls no longer pull in int/vmio.cc and thus the
  *  whole interpreter.
  *
  *  In addition, IntValue::load and IntDataSegment::load have been
  *  separated from their classes to avoid dependencies, see
  *  int/dvload.cc.
  */

#include "int/vmio.h"

IntVMSaveContext* IntVMSaveContext::save_instance;
IntVMLoadContext* IntVMLoadContext::load_instance;

/** Get current save context instance.
    \return current instance; 0 if none */
IntVMSaveContext*
IntVMSaveContext::getCurrentInstance()
{
    return save_instance;
}

/** Get current load context instance.
    \return current instance; 0 if none */
IntVMLoadContext*
IntVMLoadContext::getCurrentInstance()
{
    return load_instance;
}
